@@ -45,10 +45,21 @@ class QmakeBuilder(Builder):
         self.qt_version_str = ''
         self.qt_version_tag = ''
 
+        # Assume for the moment that this will be found on PATH.
+        self._sip_distinfo = 'sip-distinfo'
+
     def apply_user_defaults(self, tool):
         """ Set default values for user options that haven't been set yet. """
 
         if tool in Option.BUILD_TOOLS:
+            # A PEP 517 frontend will set PATH so that sip-distinfo is found on
+            # it.  However for our own frontends we want to use the version
+            # corresponding to the frontend (and, anyway, the frontend may not
+            # be on PATH).
+            if tool != 'pep517':
+                self._sip_distinfo = os.path.join(
+                        os.path.dirname(sys.argv[0]), self._sip_distinfo)
+
             # Check we have a qmake.
             if self.qmake is None:
                 self.qmake = self._find_exe('qmake')
@@ -153,7 +164,7 @@ class QmakeBuilder(Builder):
 
         inventory.close()
 
-        args = [os.path.join(os.path.dirname(sys.argv[0]), 'sip-distinfo')]
+        args = [self._sip_distinfo]
 
         args.append('--project-root')
         args.append(project.root_dir)
@@ -308,7 +319,7 @@ class QmakeBuilder(Builder):
         else:
             # Note some version of Qt5 (probably incorrectly) implements
             # 'plugin_bundle' instead of 'plugin' so we specify both.
-            pro_lines.append('CONFIG += plugin plugin_bundle')
+            pro_lines.append('CONFIG += plugin plugin_bundle no_default_rpath')
 
         if project.qml_debug:
             pro_lines.append('CONFIG += qml_debug')
@@ -361,6 +372,20 @@ target.files = %s
         buildable.installables.append(
                 QmakeTargetInstallable(module, buildable.get_install_subdir()))
 
+        # Handle an explicit Qt target directory.
+        if project.target_qt_dir:
+            rpath = '''
+CONFIG += no_qt_rpath
+linux {
+    QMAKE_RPATHDIR = %s
+}
+macx {
+    QMAKE_RPATHDIR = @loader_path/%s
+}
+''' % (project.target_qt_dir, project.target_qt_dir)
+
+            pro_lines.extend(rpath.split('\n'))
+
         # This optimisation could apply to other platforms.
         if 'linux' in self.spec and not buildable.static:
             exp = project.open_for_writing(
